#ident "$Id: x25aux.h,v 1.2 1997/10/21 20:48:48 gary Exp $"
/*****************************************************************************
 * Copyright (c) 1988-95 Digi International Inc., All Rights Reserved
 * 
 * This  software  contains  proprietary  and  confidential   information   of
 * Digi International  Inc.   By  accepting  transfer  of this copy, Recipient
 * agrees to retain this software in  confidence,  to  prevent  disclosure  to
 * others,  and  to make no  use of this software other than that for which it
 * was delivered.  This is an unpublished copyright work  Digi   International
 * Inc.    Except   as   permitted   by  federal  law,  17 USC 117, copying is
 * strictly prohibited.
 * 
 * Digi  International  Inc.  CONFIDENTIAL  -   (Digi    International    Inc.
 * Confidential  when   combined   with   the   aggregated  modules  for  this
 * product) OBJECT CODE ONLY SOURCE MATERIALS
 * 
 * (C) COPYRIGHT Digi International Inc. 1995
 * 
 * All Rights Reserved
 * 
 * US   Government   Users   Restricted   Rights   -   Use,   duplication   or
 * disclosure  restricted by GSA ADP Schedule Contract with Digi International
 * Inc.
 * 
 *****************************************************************************/

/*******************************************************************
 *
 *  SpiderX25 X25 PLP Driver
 *
 *  Copyright 1991 Spider Systems Limited
 *
 *  X25AUX.H
 *
 *
 *******************************************************************/

/*
 *	x25aux.h
 *	 /projects/common/PBRAIN/SCCS/pbrainF/dev/sys/x25/0/s.x25aux.h
 *	@(#)x25aux.h	1.8
 *
 *	Last delta created	14:36:27 9/9/92
 *	This file extracted	18:32:51 11/19/92
 *
 */

/* ----------------------------------------------------------------------
   External declarations for all routines provided in aux.c
   ---------------------------------------------------------------------- */

extern struct x25vcformat FAR *lcitovc(struct lsformat FAR *, unsigned short,int);
extern struct x25vcformat FAR *x25allocvc(int *);
extern struct lsformat        *x25alloclsap(int *);

extern int			assign_lci(struct x25vcformat FAR *);
extern int			vc_in_range(unsigned short,int *,register struct wlcfg *,int *);
extern void			tidy_user_side(struct x25vcformat FAR *);
extern void			flush_user(struct x25vcformat FAR *,int);
extern void			clr_procedure(struct x25vcformat FAR *,unsigned char,unsigned char,unsigned char,unsigned char,unsigned char);
extern void			rst_procedure(struct x25vcformat FAR *,unsigned char,unsigned char,unsigned char,unsigned char,unsigned char);
extern void			ERR_clrnoU(struct x25vcformat FAR *,int);
extern void			ERR_clrU(struct x25vcformat FAR *,int);
extern void			ERR_rstU(struct x25vcformat FAR *,int);
extern void			ERR_rstnoU(struct x25vcformat FAR *,int);
extern void			state_matrix(struct x25vcformat FAR *,unsigned char);
extern void			P4_FMT_error(struct x25vcformat FAR *,unsigned char);
extern				close_all_vcs();
extern void			dis_lsap_and_vcs(struct lsformat FAR *,unsigned char,unsigned char);
extern void			CRs_pending(struct lsformat FAR *);
extern void			xuser_gone(struct x25vcformat FAR *,unsigned char);
extern void			dec_ls_concount(struct lsformat FAR *,struct x25vcformat FAR *);
extern void			deqvc(struct lsformat FAR *,struct x25vcformat FAR *);
extern void			xfreedb(struct x25vcformat FAR *);
extern void			lfreedb(struct lsformat  FAR *);
extern void			to_P4D1(struct x25vcformat FAR *,int);
extern void			to_Lconnected(struct lsformat FAR *);
extern void			system_error(int);
extern int			buffs_status();
extern void			report_DIAG();

extern unsigned long	map_linkref();
extern unsigned long	map_snident(unsigned long);
extern unsigned long    sn_to_cfg_index();
extern struct wlcfg		*sn_to_cfg();
extern unsigned char	net_domain();
extern unsigned char	next_Dreq();
extern mblk_t			*OFF(struct Q FAR *);
extern void				ON(struct Q FAR *,mblk_t *);
extern void				xpurgeQ(struct Q FAR *);
extern NUI_ADDR			*nuifac_get();
extern void				nuifac_init();

